You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by rh...@apache.org on 2021/08/23 20:07:11 UTC

svn commit: r1892552 - /db/derby/code/trunk/java/org.apache.derby.tests/org/apache/derbyTesting/functionTests/tests/jdbc4/LoginTimeoutTest.java

Author: rhillegas
Date: Mon Aug 23 20:07:11 2021
New Revision: 1892552

URL: http://svn.apache.org/viewvc?rev=1892552&view=rev
Log:
DERBY-7124: Make it possible to run XMLBindingTest twice, back to back; commit derby-7124-01-aa-dropProcedure.diff.

Modified:
    db/derby/code/trunk/java/org.apache.derby.tests/org/apache/derbyTesting/functionTests/tests/jdbc4/LoginTimeoutTest.java

Modified: db/derby/code/trunk/java/org.apache.derby.tests/org/apache/derbyTesting/functionTests/tests/jdbc4/LoginTimeoutTest.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/org.apache.derby.tests/org/apache/derbyTesting/functionTests/tests/jdbc4/LoginTimeoutTest.java?rev=1892552&r1=1892551&r2=1892552&view=diff
==============================================================================
--- db/derby/code/trunk/java/org.apache.derby.tests/org/apache/derbyTesting/functionTests/tests/jdbc4/LoginTimeoutTest.java (original)
+++ db/derby/code/trunk/java/org.apache.derby.tests/org/apache/derbyTesting/functionTests/tests/jdbc4/LoginTimeoutTest.java Mon Aug 23 20:07:11 2021
@@ -396,8 +396,9 @@ public class LoginTimeoutTest extends Ba
         vetServerTimeout( controlConnection, connector, LONG_TIMEOUT, SUCCEED );
         vetServerTimeout( controlConnection, connector, 0, SUCCEED );
 
         // reset server timeout to default
         setServerTimeout( controlConnection, 0 );
+        controlConnection.prepareStatement( "drop procedure setLoginTimeout" ).execute();
         controlConnection.close();
     }
     private void    vetServerTimeout
@@ -396,8 +396,9 @@ public class LoginTimeoutTest extends Ba
         vetServerTimeout( controlConnection, connector, 0, SUCCEED );
 
-        // reset server timeout to default
+        // reset server timeout to default and drop the procedure
         setServerTimeout( controlConnection, 0 );